export default class _Bom {
    /**
     * 获取当前浏览器信息，返回值为一个对象，包含浏览器类型，版本号
     * 支持 IE、火狐、Chrome、Safari、Edge
     */
    static getBrowserInfo() {
        var agent = navigator.userAgent.toLowerCase();

        var regStr_ie = /msie [\d.]+;/gi;
        var regStr_ff = /firefox\/[\d.]+/gi
        var regStr_chrome = /chrome\/[\d.]+/gi;
        var regStr_saf = /version\/[\d.]+ safari/gi;
        var regStr_edge = /Edge\/[\d.]+/gi;
        //IE
        if (agent.indexOf("msie") > 0) {
            return {
                browser: "ie",
                version: agent.match(regStr_ie)[0].match(/[\d.]+/)[0],
                useragent: agent
            }
        }

        //firefox
        if (agent.indexOf("firefox") > 0) {
            return {
                browser: "firefox",
                version: agent.match(regStr_ff)[0].match(/[\d.]+/)[0],
                useragent: agent
            }
        }

        //Chrome
        if (agent.indexOf("chrome") > 0) {
            if (agent.indexOf("edge") > 0) {
                return {
                    browser: "edge",
                    version: agent.match(regStr_edge)[0].match(/[\d.]+/)[0],
                    useragent: agent
                }
            }
            return {
                browser: "chrome",
                version: agent.match(regStr_chrome)[0].match(/[\d.]+/)[0],
                useragent: agent
            }
        }

        //Safari
        if (agent.indexOf("safari") > 0 && agent.indexOf("chrome") < 0) {
            return {
                browser: "safari",
                version: agent.match(regStr_saf)[0].match(/[\d.]+/)[0],
                useragent: agent
            }
        }

        // 对 ie11 的单独处理
        if (!!window.ActiveXObject || "ActiveXObject" in window) {
            return {
                browser: "ie",
                version: 11,
                useragent: agent
            }
        }

        return {
            browser: "unknown",
            version: "unknown",
            useragent: agent
        }

    }

    /**
     * 解析 url 参数
     * @param {String} str window.location.search
     */
    static parseQueryString(str) {
        var reg = /(([^?&=]+)(?:=([^?&=]*))*)/g;
        var result = {};
        var match;
        var key;
        var value;
        while (match = reg.exec(str)) {
            key = match[2];
            value = match[3] || '';
            result[key] = decodeURIComponent(value);
        }
        return result;
    }
}